# coding: utf-8

# flake8: noqa
"""
    File Service API v2 - Token and Tenant Management

    File Service API v2 - Token and tenant management endpoints

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from istari_digital_client.storage.models.completed_part_type_def import CompletedPartTypeDef
from istari_digital_client.storage.models.create_multipart_upload_request import CreateMultipartUploadRequest
from istari_digital_client.storage.models.create_multipart_upload_response import CreateMultipartUploadResponse
from istari_digital_client.storage.models.finalize_multipart_upload_action import FinalizeMultipartUploadAction
from istari_digital_client.storage.models.finalize_multipart_upload_request import FinalizeMultipartUploadRequest
from istari_digital_client.storage.models.http_validation_error import HTTPValidationError
from istari_digital_client.storage.models.page_tenant import PageTenant
from istari_digital_client.storage.models.temporary_url import TemporaryURL
from istari_digital_client.storage.models.tenant import Tenant
from istari_digital_client.storage.models.tenant_public_key import TenantPublicKey
from istari_digital_client.storage.models.validation_error import ValidationError
from istari_digital_client.storage.models.validation_error_loc_inner import ValidationErrorLocInner
