# coding: utf-8

"""
    File Service API v2

    File Service API v2 - Main endpoints (excludes token and tenant management)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class OS(str, Enum):
    """
    OS
    """

    """
    allowed enum values
    """
    WINDOWS_11 = 'Windows 11'
    WINDOWS_10 = 'Windows 10'
    WINDOWS_SERVER_2019 = 'Windows Server 2019'
    WINDOWS_SERVER_2022 = 'Windows Server 2022'
    UBUNTU_24_DOT_04 = 'Ubuntu 24.04'
    UBUNTU_22_DOT_04 = 'Ubuntu 22.04'
    UBUNTU_20_DOT_04 = 'Ubuntu 20.04'
    RHEL_8 = 'RHEL 8'
    RHEL_9 = 'RHEL 9'
    RHEL_10 = 'RHEL 10'
    MACOS_14 = 'macOS 14'
    MACOS_15 = 'macOS 15'
    MACOS_26 = 'macOS 26'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of OS from a JSON string"""
        return cls(json.loads(json_str))
