# coding: utf-8

"""
    File Service API v2

    File Service API v2 - Main endpoints (excludes token and tenant management)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class BulkSharingAccessRelation(str, Enum):
    """
    Access relation types for resource bulk sharing operations.  This enum contains only the access relations needed for bulk sharing to avoid circular import issues with the permission module.
    """

    """
    allowed enum values
    """
    VIEWER = 'viewer'
    EDITOR = 'editor'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of BulkSharingAccessRelation from a JSON string"""
        return cls(json.loads(json_str))
