# coding: utf-8

# flake8: noqa
"""
    File Service API v2

    File Service API v2 - Main endpoints (excludes token and tenant management)

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from istari_digital_client.v2.models.access_relation import AccessRelation
from istari_digital_client.v2.models.access_relationship import AccessRelationship
from istari_digital_client.v2.models.access_resource_type import AccessResourceType
from istari_digital_client.v2.models.access_subject_type import AccessSubjectType
from istari_digital_client.v2.models.agent import Agent
from istari_digital_client.v2.models.agent_display_name import AgentDisplayName
from istari_digital_client.v2.models.agent_information import AgentInformation
from istari_digital_client.v2.models.agent_module_version import AgentModuleVersion
from istari_digital_client.v2.models.agent_modules import AgentModules
from istari_digital_client.v2.models.agent_pool import AgentPool
from istari_digital_client.v2.models.agent_pool_agent_membership import AgentPoolAgentMembership
from istari_digital_client.v2.models.agent_pool_agent_membership_with_agent import AgentPoolAgentMembershipWithAgent
from istari_digital_client.v2.models.agent_pool_user_membership import AgentPoolUserMembership
from istari_digital_client.v2.models.agent_pool_user_membership_with_user import AgentPoolUserMembershipWithUser
from istari_digital_client.v2.models.agent_pool_with_unfinished_job_count import AgentPoolWithUnfinishedJobCount
from istari_digital_client.v2.models.agent_status import AgentStatus
from istari_digital_client.v2.models.agent_status_name import AgentStatusName
from istari_digital_client.v2.models.agent_status_retention_duration import AgentStatusRetentionDuration
from istari_digital_client.v2.models.app_integration import AppIntegration
from istari_digital_client.v2.models.archive import Archive
from istari_digital_client.v2.models.archive_status import ArchiveStatus
from istari_digital_client.v2.models.archive_status_name import ArchiveStatusName
from istari_digital_client.v2.models.artifact import Artifact
from istari_digital_client.v2.models.assign_infosec_level import AssignInfosecLevel
from istari_digital_client.v2.models.auth_integration import AuthIntegration
from istari_digital_client.v2.models.auth_integration_type import AuthIntegrationType
from istari_digital_client.v2.models.auth_integration_update import AuthIntegrationUpdate
from istari_digital_client.v2.models.bulk_sharing_access_relation import BulkSharingAccessRelation
from istari_digital_client.v2.models.check_result import CheckResult
from istari_digital_client.v2.models.comment import Comment
from istari_digital_client.v2.models.content import Content
from istari_digital_client.v2.models.control_tag import ControlTag
from istari_digital_client.v2.models.control_tag_revision import ControlTagRevision
from istari_digital_client.v2.models.control_tag_status import ControlTagStatus
from istari_digital_client.v2.models.control_tagging_object_type import ControlTaggingObjectType
from istari_digital_client.v2.models.control_tagging_status import ControlTaggingStatus
from istari_digital_client.v2.models.create_document_request import CreateDocumentRequest
from istari_digital_client.v2.models.create_upstream_remote_sync import CreateUpstreamRemoteSync
from istari_digital_client.v2.models.dassault3d_experience_integration import Dassault3dExperienceIntegration
from istari_digital_client.v2.models.deprecation_reason import DeprecationReason
from istari_digital_client.v2.models.document import Document
from istari_digital_client.v2.models.document_list_item import DocumentListItem
from istari_digital_client.v2.models.dry_run_snapshot import DryRunSnapshot
from istari_digital_client.v2.models.file import File
from istari_digital_client.v2.models.file_archive_status import FileArchiveStatus
from istari_digital_client.v2.models.file_control_tagging import FileControlTagging
from istari_digital_client.v2.models.file_revision import FileRevision
from istari_digital_client.v2.models.file_revision_archive_status import FileRevisionArchiveStatus
from istari_digital_client.v2.models.filter_by import FilterBy
from istari_digital_client.v2.models.full_text_search import FullTextSearch
from istari_digital_client.v2.models.function import Function
from istari_digital_client.v2.models.function_auth_secret import FunctionAuthSecret
from istari_digital_client.v2.models.function_auth_type import FunctionAuthType
from istari_digital_client.v2.models.function_schema import FunctionSchema
from istari_digital_client.v2.models.function_status import FunctionStatus
from istari_digital_client.v2.models.function_version import FunctionVersion
from istari_digital_client.v2.models.google_drive_integration import GoogleDriveIntegration
from istari_digital_client.v2.models.http_validation_error import HTTPValidationError
from istari_digital_client.v2.models.healthcheck_report import HealthcheckReport
from istari_digital_client.v2.models.image_config import ImageConfig
from istari_digital_client.v2.models.infosec_level import InfosecLevel
from istari_digital_client.v2.models.infosec_level_object_type import InfosecLevelObjectType
from istari_digital_client.v2.models.infosec_schema import InfosecSchema
from istari_digital_client.v2.models.infosec_schema_types import InfosecSchemaTypes
from istari_digital_client.v2.models.input_schema import InputSchema
from istari_digital_client.v2.models.input_type import InputType
from istari_digital_client.v2.models.integration_type import IntegrationType
from istari_digital_client.v2.models.job import Job
from istari_digital_client.v2.models.job_agent_information import JobAgentInformation
from istari_digital_client.v2.models.job_status import JobStatus
from istari_digital_client.v2.models.job_status_message import JobStatusMessage
from istari_digital_client.v2.models.job_status_name import JobStatusName
from istari_digital_client.v2.models.json_path_config import JsonPathConfig
from istari_digital_client.v2.models.media_config import MediaConfig
from istari_digital_client.v2.models.microsoft365_integration import Microsoft365Integration
from istari_digital_client.v2.models.model import Model
from istari_digital_client.v2.models.model3_d_config import Model3DConfig
from istari_digital_client.v2.models.model_list_item import ModelListItem
from istari_digital_client.v2.models.module import Module
from istari_digital_client.v2.models.module_author import ModuleAuthor
from istari_digital_client.v2.models.module_author_manifest import ModuleAuthorManifest
from istari_digital_client.v2.models.module_type import ModuleType
from istari_digital_client.v2.models.module_version import ModuleVersion
from istari_digital_client.v2.models.module_version_status import ModuleVersionStatus
from istari_digital_client.v2.models.network_drive_data import NetworkDriveData
from istari_digital_client.v2.models.network_drive_integration import NetworkDriveIntegration
from istari_digital_client.v2.models.network_protocol import NetworkProtocol
from istari_digital_client.v2.models.new_agent import NewAgent
from istari_digital_client.v2.models.new_agent_display_name import NewAgentDisplayName
from istari_digital_client.v2.models.new_agent_information import NewAgentInformation
from istari_digital_client.v2.models.new_agent_module_version import NewAgentModuleVersion
from istari_digital_client.v2.models.new_agent_pool import NewAgentPool
from istari_digital_client.v2.models.new_agent_pool_agent_membership import NewAgentPoolAgentMembership
from istari_digital_client.v2.models.new_agent_pool_user_membership import NewAgentPoolUserMembership
from istari_digital_client.v2.models.new_agent_status import NewAgentStatus
from istari_digital_client.v2.models.new_agent_status_retention_duration import NewAgentStatusRetentionDuration
from istari_digital_client.v2.models.new_app_integration import NewAppIntegration
from istari_digital_client.v2.models.new_auth_integration import NewAuthIntegration
from istari_digital_client.v2.models.new_control_tag import NewControlTag
from istari_digital_client.v2.models.new_function_auth_secret import NewFunctionAuthSecret
from istari_digital_client.v2.models.new_function_manifest import NewFunctionManifest
from istari_digital_client.v2.models.new_function_schema_manifest import NewFunctionSchemaManifest
from istari_digital_client.v2.models.new_input_schema_manifest import NewInputSchemaManifest
from istari_digital_client.v2.models.new_job_assigned_agent import NewJobAssignedAgent
from istari_digital_client.v2.models.new_job_assigned_agent_pool import NewJobAssignedAgentPool
from istari_digital_client.v2.models.new_module_author import NewModuleAuthor
from istari_digital_client.v2.models.new_module_manifest import NewModuleManifest
from istari_digital_client.v2.models.new_operating_system import NewOperatingSystem
from istari_digital_client.v2.models.new_output_schema_manifest import NewOutputSchemaManifest
from istari_digital_client.v2.models.new_snapshot import NewSnapshot
from istari_digital_client.v2.models.new_snapshot_tag import NewSnapshotTag
from istari_digital_client.v2.models.new_system import NewSystem
from istari_digital_client.v2.models.new_system_configuration import NewSystemConfiguration
from istari_digital_client.v2.models.new_tool import NewTool
from istari_digital_client.v2.models.new_tool_version import NewToolVersion
from istari_digital_client.v2.models.new_tracked_file import NewTrackedFile
from istari_digital_client.v2.models.no_op_response import NoOpResponse
from istari_digital_client.v2.models.os import OS
from istari_digital_client.v2.models.os_type import OSType
from istari_digital_client.v2.models.object_store_sha import ObjectStoreSha
from istari_digital_client.v2.models.operating_system import OperatingSystem
from istari_digital_client.v2.models.output_schema import OutputSchema
from istari_digital_client.v2.models.output_type import OutputType
from istari_digital_client.v2.models.pdf_config import PDFConfig
from istari_digital_client.v2.models.page_agent import PageAgent
from istari_digital_client.v2.models.page_agent_pool import PageAgentPool
from istari_digital_client.v2.models.page_agent_pool_agent_membership_with_agent import PageAgentPoolAgentMembershipWithAgent
from istari_digital_client.v2.models.page_agent_pool_user_membership_with_user import PageAgentPoolUserMembershipWithUser
from istari_digital_client.v2.models.page_agent_status import PageAgentStatus
from istari_digital_client.v2.models.page_app_integration import PageAppIntegration
from istari_digital_client.v2.models.page_artifact import PageArtifact
from istari_digital_client.v2.models.page_auth_integration import PageAuthIntegration
from istari_digital_client.v2.models.page_comment import PageComment
from istari_digital_client.v2.models.page_document_list_item import PageDocumentListItem
from istari_digital_client.v2.models.page_file import PageFile
from istari_digital_client.v2.models.page_function_version import PageFunctionVersion
from istari_digital_client.v2.models.page_job import PageJob
from istari_digital_client.v2.models.page_model_list_item import PageModelListItem
from istari_digital_client.v2.models.page_module import PageModule
from istari_digital_client.v2.models.page_module_author import PageModuleAuthor
from istari_digital_client.v2.models.page_module_version import PageModuleVersion
from istari_digital_client.v2.models.page_operating_system import PageOperatingSystem
from istari_digital_client.v2.models.page_personal_access_token import PagePersonalAccessToken
from istari_digital_client.v2.models.page_resource_search_item import PageResourceSearchItem
from istari_digital_client.v2.models.page_snapshot import PageSnapshot
from istari_digital_client.v2.models.page_snapshot_item import PageSnapshotItem
from istari_digital_client.v2.models.page_snapshot_revision_search_item import PageSnapshotRevisionSearchItem
from istari_digital_client.v2.models.page_snapshot_tag import PageSnapshotTag
from istari_digital_client.v2.models.page_system import PageSystem
from istari_digital_client.v2.models.page_system_configuration import PageSystemConfiguration
from istari_digital_client.v2.models.page_tool import PageTool
from istari_digital_client.v2.models.page_tool_version import PageToolVersion
from istari_digital_client.v2.models.page_tracked_file import PageTrackedFile
from istari_digital_client.v2.models.page_type_var_customized_resource_search_item import PageTypeVarCustomizedResourceSearchItem
from istari_digital_client.v2.models.page_upstream_remote import PageUpstreamRemote
from istari_digital_client.v2.models.patch_op import PatchOp
from istari_digital_client.v2.models.permission import Permission
from istari_digital_client.v2.models.permission_resource_type import PermissionResourceType
from istari_digital_client.v2.models.permission_subject_type import PermissionSubjectType
from istari_digital_client.v2.models.permissionship import Permissionship
from istari_digital_client.v2.models.personal_access_token import PersonalAccessToken
from istari_digital_client.v2.models.personal_access_token_user_type import PersonalAccessTokenUserType
from istari_digital_client.v2.models.platform_infosec_settings import PlatformInfosecSettings
from istari_digital_client.v2.models.product import Product
from istari_digital_client.v2.models.prose_mirror_node import ProseMirrorNode
from istari_digital_client.v2.models.resource_archive_status import ResourceArchiveStatus
from istari_digital_client.v2.models.resource_control_tagging import ResourceControlTagging
from istari_digital_client.v2.models.resource_link_attrs import ResourceLinkAttrs
from istari_digital_client.v2.models.resource_search_item import ResourceSearchItem
from istari_digital_client.v2.models.resource_type import ResourceType
from istari_digital_client.v2.models.response_create_snapshot import ResponseCreateSnapshot
from istari_digital_client.v2.models.restore import Restore
from istari_digital_client.v2.models.set_platform_infosec_settings import SetPlatformInfosecSettings
from istari_digital_client.v2.models.snapshot import Snapshot
from istari_digital_client.v2.models.snapshot_item import SnapshotItem
from istari_digital_client.v2.models.snapshot_revision_search_item import SnapshotRevisionSearchItem
from istari_digital_client.v2.models.snapshot_tag import SnapshotTag
from istari_digital_client.v2.models.source import Source
from istari_digital_client.v2.models.subject_info import SubjectInfo
from istari_digital_client.v2.models.system import System
from istari_digital_client.v2.models.system_baseline import SystemBaseline
from istari_digital_client.v2.models.system_configuration import SystemConfiguration
from istari_digital_client.v2.models.teamwork_cloud_data import TeamworkCloudData
from istari_digital_client.v2.models.teamwork_cloud_integration import TeamworkCloudIntegration
from istari_digital_client.v2.models.token import Token
from istari_digital_client.v2.models.token_with_properties import TokenWithProperties
from istari_digital_client.v2.models.tool import Tool
from istari_digital_client.v2.models.tool_include import ToolInclude
from istari_digital_client.v2.models.tool_version import ToolVersion
from istari_digital_client.v2.models.tracked_file import TrackedFile
from istari_digital_client.v2.models.tracked_file_specifier_type import TrackedFileSpecifierType
from istari_digital_client.v2.models.update_access_relationship import UpdateAccessRelationship
from istari_digital_client.v2.models.update_access_relationship_list import UpdateAccessRelationshipList
from istari_digital_client.v2.models.update_access_relationship_list_item import UpdateAccessRelationshipListItem
from istari_digital_client.v2.models.update_control_tag import UpdateControlTag
from istari_digital_client.v2.models.update_document_request import UpdateDocumentRequest
from istari_digital_client.v2.models.update_system import UpdateSystem
from istari_digital_client.v2.models.update_tag import UpdateTag
from istari_digital_client.v2.models.update_tool import UpdateTool
from istari_digital_client.v2.models.upload_as import UploadAs
from istari_digital_client.v2.models.upstream_remote import UpstreamRemote
from istari_digital_client.v2.models.upstream_remote_info import UpstreamRemoteInfo
from istari_digital_client.v2.models.upstream_remote_sync import UpstreamRemoteSync
from istari_digital_client.v2.models.upstream_remote_sync_status import UpstreamRemoteSyncStatus
from istari_digital_client.v2.models.usability_status_name import UsabilityStatusName
from istari_digital_client.v2.models.usability_status_params import UsabilityStatusParams
from istari_digital_client.v2.models.user import User
from istari_digital_client.v2.models.user_control_tagging import UserControlTagging
from istari_digital_client.v2.models.user_model_inputs import UserModelInputs
from istari_digital_client.v2.models.user_state import UserState
from istari_digital_client.v2.models.user_state_option import UserStateOption
from istari_digital_client.v2.models.user_type import UserType
from istari_digital_client.v2.models.validation_error import ValidationError
from istari_digital_client.v2.models.validation_error_loc_inner import ValidationErrorLocInner
from istari_digital_client.v2.models.view_config import ViewConfig
from istari_digital_client.v2.models.windchill_integration import WindchillIntegration
