# coding: utf-8

"""
    File Service API v3

    File Service API v3 - All v3 endpoints

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ResourceTypeDto(str, Enum):
    """
    Enum for resource types.
    """

    """
    allowed enum values
    """
    MODEL = 'model'
    ARTIFACT = 'artifact'
    FILE = 'file'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ResourceTypeDto from a JSON string"""
        return cls(json.loads(json_str))
